CZ 🔶 Binance (@cz_binance) | nitter
Description: CEO @binance, holder of #bnb #btc

CZ 🔶 Binance
@cz_binance

CEO @binance, holder of #bnb #btc

binance.com
Joined August 2017

- Tweets 8,504
- Following 1,690
- Followers 8,580,999
- Likes 16,393

903 Photos and videos
903 Photos and videos

- Tweets
- Tweets & Replies
- Media
- Search

Pinned Tweet
CZ 🔶 Binance
@cz_binance
Jan 2
Will try to keep 2023 simple. Spend more time on less things. Do's and Don'ts. 1. Education 2. Compliance 3. Product & Service 4. Ignore FUD, fake news, attacks, etc. In the future, would appreciate if you can link to this post when I tweet "4". 🙏
30,767
26,164
3,465
61,475
CZ 🔶 Binance
@cz_binance
17h
1. Education. 147 graduates have secured IT-related jobs from the IT Generation project in Ukraine, a tech scholarship program supported by @BinanceBCF. » binance.com/en/blog/charity/…
482
426
1,953
59,063
CZ 🔶 Binance
@cz_binance
18h
Let’s X it… 🤷‍♂️😂
1,909
1,484
12,071
CZ 🔶 Binance retweeted
Srijal AKA Spidey @spidey_cyp155
Jul 24
#Binancestanding strong despite storms. - US Fud - Paid attacks - Fake news - Hate attacks - Insolvency false reports Despite so much FUD & attacks, the reserves are rock solid. This shows the trust @cz_binance has built over the years. 🫡 #InBinanceWeTrust
139
182
950
CZ 🔶 Binance
@cz_binance
Jul 24
Also from 6 years ago, an article I wrote on FUD. Yes, it's a time-old concept. It hasn't changed. And sadly, it will go on for a while. steemit.com/binance/@czbinan…

## FUD — Steemit

FUD is a new word, but not a new concept. It’s age-old. It has always been around, and it will always be around. It… by czbinance

steemit.com
584
665
2,955
CZ 🔶 Binance
@cz_binance
Jul 23
Someone sent this to me, an article I wrote 6 years ago. The project mentioned currently has a market cap of less than $1m. It's a good group of guys, but probably distracted by too much money. Start small and grow big, not the other way around. steemit.com/binance/@czbinan…

## I Don't Like Big ICOs — Steemit

This is CZ, CEO of This is my first post on Steemit, and a highly subjective one. Last night, I was at a party in… by czbinance

steemit.com
559
657
3,292
CZ 🔶 Binance
@cz_binance
Jul 23
CR7 is a cool dude.
Binance @binance
Jul 20
A training session like no other. Holders of the rarest ForeverCR7: The GOAT NFTs will be able to train with @Cristiano Ronaldo in-person. Here's a first look at what they'll get up to 👉
419
370
2,422
CZ 🔶 Binance
@cz_binance
Jul 22
Technology advances are always a double edged sword, some bad mostly good.
1,019
860
4,558
CZ 🔶 Binance
@cz_binance
Jul 22
When people see me in a restaurant, they say: “oh it’s the Binance guy.” 😂
1,794
1,421
11,317
CZ 🔶 Binance retweeted
Binance @binance
Jul 20
A training session like no other. Holders of the rarest ForeverCR7: The GOAT NFTs will be able to train with @Cristiano Ronaldo in-person. Here's a first look at what they'll get up to 👉

##

Click here to bid on the SSR NFTs now!

binance.com
519
624
1,917
CZ 🔶 Binance
@cz_binance
Jul 21
#Binance France🇫🇷 released its first audited financial statements today. Binance France a publié aujourd’hui ses premiers états financiers audités. binance.com/fr/blog/ecosyste…

## Binance France publishes 2022 accounts - what do they say and FAQ | Blog Binance

Discover the audited financial statements of Binance France for the year 2022 in this comprehensive analysis. Binance France has released its first audited financial statements for 2022, including...

binance.com
662
1,100
4,314
CZ 🔶 Binance
@cz_binance
Jul 21
Be careful with phishing and other social engineering scams. Best to enable 2FA with a hardware device (Yubikey) on all crypto exchanges. cybernews.com/news/whatsapp-…

## WhatsApp data leaked: 500 million user records for sale online | Cybernews

Someone is allegedly selling up-to-date mobile phone numbers of nearly 500 million WhatsApp users. A data sample investigated by Cybernews likely confirms this to be true.

cybernews.com
616
1,407
4,651
CZ 🔶 Binance
@cz_binance
Jul 20
They say usually, faster is better. 🙏
Binance @binance
Jul 20
Using your feedback, #Binance has now reduced the min. number of blocks for crediting of deposits on the Ethereum, Arbitrum & Optimism networks. ETH: 🔸 12 to 6 blocks 🔸 Times down from ~25 mins to ~13 mins ARB & OP: 🔸 100 to 1 block 🔸 Times down from ~7 mins to ~1 min
602
730
3,422
CZ 🔶 Binance
@cz_binance
Jul 20
Experience it here. ➡️ enterthedimension.com/?ref=A…
92
57
318
Show this thread
CZ 🔶 Binance
@cz_binance
Jul 20
The first global music tour powered by Web3. #BinanceAfterHours
Abel Tesfaye @theweeknd
Jul 20
see you tonight Barcelona 🇪🇸 Thanks to @binance, you can experience #BinanceAfterHours virtually too. Start here 🎭➡ enterthedimension.com/?ref=B…
482
580
2,546
Show this thread
CZ 🔶 Binance
@cz_binance
Jul 19
Positive life starts with positive energy. Be full of positive energy in life. 💪
1,971
2,631
13,440
CZ 🔶 Binance
@cz_binance
Jul 19
The quarterly #BNB burn is done, according to the public algorithm. I was told there will be some more on-chain (large) transactions shortly, to further distribute/spread the coins to more addresses. Nothing to be alarmed about. 🙏
886
1,033
5,449
CZ 🔶 Binance
@cz_binance
Jul 19
🔥
1,839
1,355
10,607
CZ 🔶 Binance retweeted
Binance @binance
Jul 17
6 years of #Binance Built as a community, celebrated as a community. Here’s a look at what we got up to for #BinanceTurns6!
638
871
2,802
100,099
Show this thread
CZ 🔶 Binance
@cz_binance
Jul 17
I learned today that a guy who is constantly spreading FUD about @Binance was just because he pitched his project to Binance Labs and we didn't invest. Feel really sad for him. I hope he eventually finds his way out of it, and actually focus on his own project. 😂
Yi He @heyibinance
Jul 11
When I am puzzled by the continuous Binance FUD from a “KOL”…I apologize for not always checking my private messages.🤷‍♀️
1,111
1,341
6,140
CZ 🔶 Binance
@cz_binance
Jul 17
If you only invest during the bull market, then you are by definition, only buying high. 🤷‍♂️ Not investment advice. Just saying.
1,942
5,111
17,788
Load more